@@ -51,6 +51,17 @@ class PseudocodefrLexer(RegexLexer):
 
         yield match.start(), Name.Constant, greek_letter
 
+    def symb_replace(lexer, match):
+        symbol = match.group(0)
+        
+        S = ('\\varnothing', '\\void', '\\in', '\\notin', '\\subset', '\\supset', '\\cap', '\\cup')
+        R = ('∅'          , '∅'     , '∈'   , '∉'       , '⊂'       , '⊃'       , '⋂'  , '⋃')
+
+        if symbol in S:
+            symbol = R[S.index(symbol)]
+
+        yield match.start(), Name.Constant, symbol
+
     def scomment(lexer, match):
         s = match.group(1).lower().strip()
         c = Comment
@@ -75,23 +86,28 @@ class PseudocodefrLexer(RegexLexer):
                     (r'[\s]+', Text)
             ],
             'core':[ # Statements
-                    (r'\b(debut|début|fin|si|alors|sinon|fin[_ ]si|tant[ _]que|tantque|fin[ _]tantque|faire|répéter'
+                    (r'\b(debut|début|fin|si|alors|sinon|fin[_ ]si|tant[ _]que|tantque|fin[ _]tantque|faire|répéter|'
                     r'repeter|type|structure|fin[ _]structure|fonction|procédure|procedure|retourner|renvoyer|'
                     r'pour|variant|allant|de|fin[ _]pour|à|déclarations?|jusque|spécialise|specialise|comporte|super|public|privé|protégé|'
+                    r'est|vaut|prend la valeur|affecter|'
                     r'classe'
                     r')\s*\b', Keyword),
 
                     # Data Types
-                    (r'\b(entiers?|chaines?|chaînes?|réels?|reels?|caractères?|caracteres?|booléens?|'
-                    r'booleens?|tableaux?|rien)\s*\b', 
+                    (r'\b(entiers?|chaines?|chaînes?|réels?|reels?|flottants?|caractères?|caracteres?|booléens?|'
+                    r'booleens?|tableaux?|listes?|files?|piles?|rien)\s*\b', 
                     Keyword.Type),
 
-                    # Greek Letters
-                    (r'(\\alpha|\\beta|\\gamma|\\delta|\\epsilon|\\zeta|\\eta|\\theta|\\iota|\\kappa|\\lambda|\\mu|\\nu|\\xi|\\pi|\\rho|\\sigma|\\tau|\\upsilon|\\phi|\\chi|\\psi|\\omega|\\Alpha|\\Beta|\\Gamma|\\Delta|\\Epsilon|\\Zeta|\\Eta|\\Theta|\\Iota|\\Kappa|\\Lambda|\\Mu|\\Nu|\\Xi|\\Pi|\\Rho|\\Sigma|\\Tau|\\Upsilon|\\Phi|\\Chi|\\Psi|\\Omega)',
+                    # Greek Letters Replace
+                    (r'(\\alpha|\\beta|\\gamma|\\delta|\\epsilon|\\zeta|\\eta|\\theta|\\iota|\\kappa|\\lambda|\\mu|\\nu|\\xi|\\pi|\\rho|\\sigma|\\tau|\\upsilon|\\phi|\\chi|\\psi|\\omega|'
+                    r'\\Alpha|\\Beta|\\Gamma|\\Delta|\\Epsilon|\\Zeta|\\Eta|\\Theta|\\Iota|\\Kappa|\\Lambda|\\Mu|\\Nu|\\Xi|\\Pi|\\Rho|\\Sigma|\\Tau|\\Upsilon|\\Phi|\\Chi|\\Psi|\\Omega)',
                     greek_replace),
 
+                    # Symbols Replace
+                    (r'(\\varnothing|\\void|\\in|\\notin|\\subset|\\supset|\\cap|\\cup)',
+                    symb_replace),
 
-                    (r'\b(vrai|faux|nil)\s*\b',
+                    (r'\b(vrai|faux|nil|nul|vide)\s*\b',
                     Name.Constant),
                     
                     # Operators
